@@ -1,10 +1,10 @@
 #' Plot `seroincidence.by` log-likelihoods
 #' @description
 #' Plots log-likelihood curves by stratum, for `seroincidence.by` objects
-#' @param object a '"seroincidence.by"' object (from [est.incidence.by()])
+#' @param object a '"seroincidence.by"' object (from [est_seroincidence_by()])
 #' @param ncol number of columns to use for panel of plots
 #' @inheritDotParams autoplot.seroincidence
-#' @return an object of class `"ggarrange"`, which is a [ggplot2::ggplot()] or a [list()] of [ggplot2::ggplot()]s.
+#' @return a `"ggarrange"` object: a single or [list()] of [ggplot2::ggplot()]s
 #' @export
 #' @examples
 #'\donttest{
@@ -21,10 +21,12 @@
 #' noise <-
 #'   example_noise_params_pk
 #'
-#' est2 <- est.incidence.by(
+#' est2 <- est_seroincidence_by(
 #'   strata = c("catchment"),
 #'   pop_data = xs_data,
-#'   curve_params = curve,
+#'   sr_params = curve,
+#'   curve_strata_varnames= NULL,
+#'   noise_strata_varnames = NULL,
 #'   noise_params = noise,
 #'   antigen_isos = c("HlyE_IgG", "HlyE_IgA"),
 #'   #num_cores = 8, #Allow for parallel processing to decrease run time
@@ -34,7 +36,7 @@
 #' # Plot the log-likelihood curve
 #' autoplot(est2)
 #'}
-autoplot.seroincidence.by = function(
+autoplot.seroincidence.by <- function(
     object,
     ncol = min(3, length(object)),
     ...) {
@@ -45,7 +47,7 @@ autoplot.seroincidence.by = function(
   if (!attr(object, "graphs_included")) {
     stop(
       "Graphs cannot be extracted; ",
-      "`build_graph` was not `TRUE` in the call to `est.incidence.by()`"
+      "`build_graph` was not `TRUE` in the call to `est_seroincidence_by()`"
     )
     figure <- NULL
   }
@@ -53,8 +55,7 @@ autoplot.seroincidence.by = function(
   labels <- names(object)
   figs <- lapply(object, FUN = autoplot.seroincidence, ...)
 
-  for (i in 1:length(figs))
-  {
+  for (i in seq_along(figs)){
     figs[[i]] <- figs[[i]] + ggplot2::ggtitle(labels[i])
   }
 
