@@ -8,8 +8,8 @@
 #' library(magrittr)
 #'
 #' xs_data <-
-#'   serocalculator_example("example_pop_data.csv") %>%
-#'   read.csv() %>%
+#'   serocalculator_example("example_pop_data.csv") |>
+#'   read.csv() |>
 #'   as_pop_data()
 #'
 #' check_pop_data(xs_data, verbose = TRUE)
@@ -27,24 +27,24 @@ check_pop_data <- function(pop_data, verbose = FALSE) {
   }
 
   missing_age <- is.element(
-    pop_data %>% get_age_var(),
-    pop_data %>% names()
+    pop_data |> get_age_var(),
+    pop_data |> names()
   )
 
   if (!missing_age) {
     "Argument {.arg pop_data} is missing column
-    {.var {pop_data %>% get_age_var()}}(age, in years)" %>%
+    {.var {pop_data |> get_age_var()}} (age, in years)" |>
       cli::cli_abort(class = "missing-var")
   }
 
   missing_value <- is.element(
-    pop_data %>% get_value_var(),
-    pop_data %>% names()
+    pop_data |> get_values_var(),
+    pop_data |> names()
   )
 
   if (!missing_value) {
     "Argument {.arg pop_data} is missing column
-    {.var {pop_data %>% get_value_var()}} (antibody measurement)" %>%
+    {.var {pop_data |> get_values_var()}} (antibody measurement)" |>
       cli::cli_abort(class = "missing-var")
   }
 
