@@ -7,19 +7,23 @@
 #' consistent API.
 #' @keywords internal
 #' @export
-fdev <- function(lambda, csdata, lnpars, cond)
-{
+fdev <- function(lambda, csdata, lnpars, cond) {
   lifecycle::deprecate_warn("1.0.0", "fdev()", "f_dev()")
   f_dev(lambda, csdata, lnpars, cond)
 }
 
-#' @title Calculate negative log-likelihood (deviance) for one antigen:isotype pair and incidence rate
+#' @title Calculate negative log-likelihood (deviance)
+#' for one antigen:isotype pair and one incidence rate
 #'
 #' @details interface with C lib `serocalc.so`
-#' @param lambda [numeric()] incidence parameter, in events per person-year
-#' @param csdata cross-sectional sample data containing variables `value` and `age`
-#' @param lnpars longitudinal antibody decay model parameters `alpha`, `y1`, and `d`
-#' @param cond measurement noise parameters `nu`, `eps`, `y.low`, and `y.high`
+#' @param lambda [numeric()] incidence parameter,
+#' in events per person-year
+#' @param csdata
+#' cross-sectional sample data containing variables `value` and `age`
+#' @param lnpars
+#' longitudinal antibody decay model parameters `alpha`, `y1`, and `d`
+#' @param cond
+#' measurement noise parameters `nu`, `eps`, `y.low`, and `y.high`
 #' @returns a [numeric()] negative log-likelihood,
 #' corresponding to input `lambda`
 #' @keywords internal
@@ -51,7 +55,6 @@ fdev <- function(lambda, csdata, lnpars, cond)
 #' cur_data <-
 #'   xs_data %>%
 #'   dplyr::filter(
-#'    .data$catchment == "dhaka",
 #'    .data$antigen_iso == cur_antibody) %>%
 #'   dplyr::slice_head(n = 100)
 #'
@@ -64,7 +67,7 @@ fdev <- function(lambda, csdata, lnpars, cond)
 #'   noise_params %>%
 #'   dplyr::filter(.data$antigen_iso == cur_antibody)
 #'
-#' if(!is.element('d', names(cur_curve_params)))
+#' if (!is.element('d', names(cur_curve_params)))
 #' {
 #'   cur_curve_params <-
 #'     cur_curve_params %>%
@@ -81,50 +84,54 @@ fdev <- function(lambda, csdata, lnpars, cond)
 #'     cond = cur_noise_params
 #'   )
 #'}
-f_dev0 <- function(
-      lambda,
-      csdata,
-      lnpars,
-      cond) {
-    res <- 0
-    lambda <- as.double(lambda)
-    y <- as.double(get_value(csdata))
-    a <- as.double(get_age(csdata))
-    nsubj <- as.integer(nrow(csdata))
-    y1 <- as.double(lnpars$y1)
-    alpha <- as.double(lnpars$alpha)
-    d <- as.double(lnpars$d)
-    nmc <- as.integer(length(y1))
-    step <- as.double(max(y1) / 100) # hack for numerical integrations
-    nu <- as.double(cond$nu)
-    eps <- as.double(cond$eps)
-    y.low <- as.double(cond$y.low)
-    y.high <- as.double(cond$y.high)
-    llpp <- .C(
-      "negloglik",
-      res = as.double(res),
-      lambda = lambda,
-      y = y,
-      a = a,
-      nsubj = nsubj,
-      nu = nu,
-      eps = eps,
-      step = step,
-      y.low = y.low,
-      y.high = y.high,
-      y1 = y1,
-      alpha = alpha,
-      d = d,
-      nmc = nmc
-    )
-    return(llpp$res)
-  }
+f_dev0 <- function(lambda,
+                   csdata,
+                   lnpars,
+                   cond) {
+  res <- 0
+  lambda <- as.double(lambda)
+  y <- as.double(get_values(csdata))
+  a <- as.double(get_age(csdata))
+  nsubj <- as.integer(nrow(csdata))
+  y1 <- as.double(lnpars$y1)
+  alpha <- as.double(lnpars$alpha)
+  d <- as.double(lnpars$d)
+  nmc <- as.integer(length(y1))
+  step <- as.double(max(y1) / 100) # hack for numerical integrations
+  nu <- as.double(cond$nu)
+  eps <- as.double(cond$eps)
+  y_low <- as.double(cond$y.low)
+  y_high <- as.double(cond$y.high)
+  llpp <- .C(
+    "negloglik",
+    res = as.double(res),
+    lambda = lambda,
+    y = y,
+    a = a,
+    nsubj = nsubj,
+    nu = nu,
+    eps = eps,
+    step = step,
+    y.low = y_low,
+    y.high = y_high,
+    y1 = y1,
+    alpha = alpha,
+    d = d,
+    nmc = nmc
+  )
+  return(llpp$res)
+}
 
-#' @title Calculate negative log-likelihood (deviance) for one antigen:isotype pair and several values of incidence
+#' @title Calculate negative log-likelihood (deviance)
+#' for one antigen:isotype pair and several values of incidence
 #'
-#' @description Calculates negative log-likelihood (deviance) for one antigen:isotype pair and several values of incidence (`lambda`).
-#' @details Vectorized version of [f_dev0()]; interface with C lib `serocalc.so`
-#' @param lambda a [numeric] vector of incidence parameters, in events per person-year
+#' @description Calculates negative log-likelihood (deviance)
+#' for one antigen:isotype pair and several values of incidence
+#' (`lambda`).
+#' @details Vectorized version of [f_dev0()];
+#' interface with C lib `serocalc.so`
+#' @param lambda a [numeric] vector of incidence parameters,
+#' in events per person-year
 #' @inheritParams f_dev
 #' @returns a [numeric] vector of negative log-likelihoods,
 #' corresponding to the elements of input `lambda`
