@@ -1,14 +1,10 @@
-.makeStrata <- function(data, strata = "")
-{
+.makeStrata <- function(data, strata = "") {
   dataStrata <- data
 
-  if (all(strata != ""))
-  {
-    if(all(strata %in% names(data)))
-    {
+  if (all(strata != "")) {
+    if (all(strata %in% names(data))) {
       dataStrata$Stratum <- interaction(dataStrata[, strata])
-    } else
-    {
+    } else {
       return(dataStrata) # no stratum variable
     }
   } else {
