@@ -1,4 +1,3 @@
-
 #' Calculate negative log-likelihood
 #' @description
 #' Same as [log_likelihood()], except negated and requiring lambda on log scale (used in combination with `nlm()`, to ensure that the optimization search doesn't stray into negative values of `lambda`).
@@ -7,7 +6,6 @@
 
 #' @return the negative log-likelihood of the data with the current parameter values
 #' @keywords internal
-.nll = function(log.lambda, ...)
-{
-  -log_likelihood(lambda = exp(log.lambda),...)
+.nll <- function(log.lambda, ...) {
+  -log_likelihood(lambda = exp(log.lambda), ...)
 }
