@@ -1,7 +1,7 @@
 test_that("df_to_array() produces consistent results", {
-  library(dplyr)
-  library(tidyr)
-  df <- iris %>%
+  withr::local_package("dplyr")
+  withr::local_package("tidyr")
+  df <- iris |>
     tidyr::pivot_longer(
       names_to = "parameter",
       cols = c(
@@ -10,9 +10,9 @@ test_that("df_to_array() produces consistent results", {
         "Petal.Width",
         "Petal.Length"
       )
-    ) %>%
+    ) |>
     mutate(parameter = factor(parameter, levels = unique(parameter)))
-  arr <- df %>%
+  arr <- df |>
     serocalculator:::df_to_array(dim_var_names = c("parameter", "Species"))
-  arr %>% expect_snapshot_value(style = "serialize")
+  arr |> expect_snapshot_value(style = "serialize")
 })
