@@ -6,9 +6,10 @@ test_that("`plot_curve_params_one_ab()` produces consistent results", {
       t1 = 9.5,
       alpha = 0.01,
       r = 1,
+      iter = 1,
       antigen_iso = "test"
     ) |>
-    as_curve_params()
+    as_sr_params()
 
 
   fig1 <-
