@@ -8,7 +8,9 @@ test_that("`serocalculator_example()` works", {
 
 
   files1 <- serocalculator_example()
-  files2 <- c("example_curve_params.csv", "example_curve_params.rds", "example_noise_params.csv", "example_noise_params.rds", "example_pop_data.csv", "example_pop_data.rds")
+  files2 <- c("example_curve_params.csv", "example_curve_params.rds",
+              "example_noise_params.csv", "example_noise_params.rds",
+              "example_pop_data.csv", "example_pop_data.rds")
 
   expect_equal(files1, files2)
 })
